Crate axpoll

Crate axpoll 

Typed readiness capabilities independent of a queue or scheduler implementation.

Structs

IoEvents
I/O readiness events.
PollRegistrar
Owns every readiness registration made by one polling attempt.

Enums

ExclusiveConsumer
Marker for a waiter that competes to consume one readiness event.
RegistrationMode
Selection mode attached to one readiness registration.
SharedObserver
Marker for a readiness observer that does not consume an event.

Traits

ExclusiveRegistrationSink
Capability for adding exclusive registrations to an owned attempt.
PollRegistration
An owned source registration whose drop cancels the exact registered entry.
PollSource
A readiness source capable of creating owned registrations.
Pollable
A value that reports I/O readiness and publishes owned registrations.
SharedRegistrationSink
Capability for adding shared registrations to an owned attempt.